@@ -6,7 +6,7 @@
 #  - deal with configuration files
 #  - deal with log files
 #
-# $Id: SLBackup.pm,v 1.4 2005/08/28 13:16:34 werner-guest Exp $
+# $Id: SLBackup.pm,v 1.6 2007-12-22 19:48:18 finnarne-guest Exp $
 #
 # Most of the code in this module is copied from the
 # LRRD project (http://www.linpro.no/project/lrrd/)
@@ -42,7 +42,8 @@ sub slbackup_readconfig {
 	return undef;
     }
 
-    my $conffile = new Config::General($conf);
+    my $conffile = new Config::General(-ConfigFile => $conf,
+                                       -CComments => 0);
     my $config = { $conffile->getall };
     return ($config);
 }
